# Java 控制流语句

> 原文： [https://javatutorial.net/java-control-flow-statements](https://javatutorial.net/java-control-flow-statements)

Java 中的控制流语句允许您在满足特殊条件时运行或跳过代码块。 您将在程序中大量使用控制语句，本教程将说明如何执行此操作。

## `if`语句

Java 中的`if`语句的工作原理与大多数编程语言完全相同。 借助`if`，您可以选择在满足预定义条件时执行特定的代码块。 Java 中`if`语句的结构如下所示：

```java
if (condition) {
	// execute this code
}
```

条件是布尔值。 布尔值意味着它可以是`true`或`false`。 例如，您可以将数学方程式作为条件。 看这个完整的例子：

```java
public class FlowControlExample {
	public static void main(String[] args) {
		int age = 2;
		System.out.println("Peter is " + age + " years old");

		if (age < 4) {
			System.out.println("Peter is a baby");
		}
	}
}
```

输出为：

```java
Peter is 2 years old
Peter is a baby
```

在上面的示例中，我们检查年龄是否小于 4。将年龄设置为 2，布尔条件`2 < 4`为`true`，结果我们打印`"Peter is a baby"`。 如果我们将年龄更改为大于 3 的任何值，则该块中的代码将不再执行，并且不会打印`"Peter is a baby"`。

## Java 中的比较运算符

使用此运算符创建布尔结果

`<`小于

`<=`小于或等于

`>`大于

`>=`大于或等于

`==`等于

`!=`不等于

## Java 中的条件运算符

`&&`和`||`运算符对两个布尔表达式执行有条件 AND 和有条件 OR 运算。

```java
int a = 2;
int b = 2;
int c = 5;

if (a == 2 && b == 2) {
	System.out.println("A and B are equeal to 2");
}

if (a == 5 || c == 5) {
	System.out.println("A or C is equal to 5");
}
```

结果是

```java
A and B are equeal to 2
A or C is equal 5
```

## `if-else`语句

通过此语句，您可以控制满足条件的情况以及其他情况。 看下面的代码

```java
public class FlowControlExample {
	public static void main(String[] args) {
		int age = 10;
		System.out.println("Peter is " + age + " years old");

		if (age < 4) {
			System.out.println("Peter is a baby");
		} else {
			System.out.println("Peter is not a baby anymore");
		}
	}
}
```

结果是

```java
Peter is 10 years old
Peter is not a baby anymore
```

因为我们给年龄的值大于 3，所以执行`else`语句

我将再展示一个带有`if else`语句和条件运算符的示例

```java
public class FlowControlExample {
	public static void main(String[] args) {
		int age = 14;
		System.out.println("Peter is " + age + " years old");

		if (age < 4) {
			System.out.println("Peter is a baby");
		} else if (age >= 4 && age < 14) {
			System.out.println("Peter is a child");
		} else if (age >= 14 && age < 18) {
			System.out.println("Peter is a teenager");
		} else if (age >= 18 && age < 68) {
			System.out.println("Peter is adult");
		} else {
			System.out.println("Peter is an old men");
		}
	}
}
```

## `switch`语句

在某些情况下，您可以避免在代码中使用多个 if-s 并使代码看起来更好。 为此，可以使用`switch`语句。 看下面的 java `switch`示例

```java
public class SwitchExample {
	public static void main(String[] args) {
		int numOfAngles = 3;

		switch (numOfAngles) {
		case 3:
			System.out.println("triangle");
			break;
		case 4:
			System.out.println("rectangle");
			break;
		case 5:
			System.out.println("pentagon");
			break;
		default:
			System.out.println("Unknown shape");
		}
	}
}
```

`switch`有一把键和一个或多个情况。 在我们的示例中，键为`numOfAngles`，当我们将 3、4 和 5 用作`switch`语句的值时，我们处理停止点。 如果我们传递的值不同于 3、4 或 5 ，则默认执行。 另请注意，在每种情况下，中断。 如果我们不包括`break`，则程序将运行到下一种情况。 例如，如果我们删除情况 3 的中断，则在上面的示例中将执行情况 3 和情况 4。

在我的下一个教程 [Java 循环](http://javatutorial.net/java-loops "Java Loops")中，我将解释如何在 Java 中使用循环。